@@ -5,7 +5,7 @@
 #
 # $Id$
 #
-# Copyright B. Cornec 2007
+# Copyright B. Cornec 2007-2016
 # Provided under the GPL v2
 
 package ProjectBuilder::Changelog;
@@ -16,6 +16,7 @@ use English;
 use Date::Manip;
 use POSIX qw(strftime);
 use lib qw (lib);
+use Text::Wrap;
 use ProjectBuilder::Version;
 use ProjectBuilder::Base;
 use ProjectBuilder::Conf;
@@ -69,7 +70,7 @@ my $pbextdir = $pb->{'extdir'};
 my $pbsuf = $pb->{'pbos'}->{'suffix'};
 my $OUTPUT = shift;
 my $doit = shift;
-my $chglog = $pb->{'chglog'} || undef;
+my $chglog = $pb->{'chglog'};
 
 my $log = "";
 
@@ -190,10 +191,11 @@ while (<INPUT>) {
 		}
 
 	$tmp = <INPUT>;	
-	while ($tmp !~ /^$/) {
+	while ((defined $tmp) && ($tmp !~ /^$/)) {
 		if ($dtype eq "deb") {
 			$tmp =~ s/^- //;
-			print $OUTPUT "  * $tmp";
+    		$Text::Wrap::columns = 80;
+			print $OUTPUT "  * ".wrap('','    ',$tmp);
 		} elsif ($dtype eq "rpm") {
 			print $OUTPUT "$tmp";
 		} else {
